#
# spec file for package python-fluent.syntax
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-fluent.syntax
Version:        0.19.0
Release:        1.6
Summary:        Localization library for expressive translations
License:        Apache-2.0
URL:            https://github.com/projectfluent/python-fluent
Source:         https://github.com/projectfluent/python-fluent/archive/refs/tags/fluent.syntax@%{version}.tar.gz#/fluent.syntax-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module typing-extensions >= 3.7}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-typing-extensions >= 3.7
Provides:       python-fluent = %{version}
Obsoletes:      python-fluent < %{version}
BuildArch:      noarch
%python_subpackages

%description
Localization library for expressive translations.

%prep
%autosetup -p1 -n python-fluent-fluent.syntax-%{version}

%build
pushd fluent.syntax
%pyproject_wheel
popd

%install
pushd fluent.syntax
%pyproject_install
popd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd fluent.syntax
%pytest
popd

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/fluent
%{python_sitelib}/fluent.syntax-%{version}.dist-info

%changelog
* Fri Jan 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Package renamed from fluent to fluent.syntax.
- Update to 0.19.0:
  * Drop support for Python 2.7 and 3.5 & support for Python 3.6 through 3.9
  * Treat tab as text, not whitespace
  * Add type hints
  * Fix serialization of multiline patterns starting with special characters.
  * Removal of deprecated `BaseNode.traverse` method.
  * Refactor `Visitor` and `Transformer` into `fluent.syntax.visitor`
    (from `.ast`)
  * Parser fix for whitespace before call arguments.
  * Parser fix for selector expressions being too lenient.
  * The serializer had a bug when asked to serialize empty comments.
  * Support Fluent Syntax 1.0.
  * Flatten complex reference expressions.
  * Remove `VariantLists`.
  * Rename `StringLiteral.raw` to `value`.
  * Rename `args` to `arguments`.
  * Make `BaseNode.equals` stricter when comparing lists.
  * Remove `FluentSerializer.serialize_expression`.
  * The `Visitor` API introduced in 0.11 was changed to align more with
    what Python's `ast.Visitor` does.
  * There are two new APIs in `fluent.syntax.ast`, `Visitor` and
    `Transformer`.
  * The API `BaseNode.traverse` is deprecated and will be removed in a
    future release.
* Mon May 17 2021 pgajdos@suse.com
- use %%pytest macro
* Sat Jan 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, used by translate-toolkit
